@@ -5,6 +5,8 @@ from making_with_code_cli.teach.status import status
 from making_with_code_cli.teach.log import log
 from making_with_code_cli.teach.patch import patch
 from making_with_code_cli.teach.check import check
+from making_with_code_cli.teach.section import section
+from making_with_code_cli.teach.student import student
 
 @click.group()
 def teach():
@@ -16,3 +18,5 @@ teach.add_command(status)
 teach.add_command(log)
 teach.add_command(patch)
 teach.add_command(check)
+teach.add_command(section)
+teach.add_command(student)
