@@ -29,7 +29,7 @@ measures = {
 
 @click.command()
 @click.option("--config", help="Path to config file (default: ~/.mwc)")
-@click.option("-g", "--group", help="Filter by group name")
+@click.option("-s", "--section", help="Filter by section name/slug")
 @click.option("-c", "--course", help="Filter by course name")
 @click.option("-u", "--user", help="Filter by username")
 @click.option("-n", "--unit", help="Filter by unit name/slug")
@@ -37,37 +37,37 @@ measures = {
 @click.option("-v", "--measure", default="commits", type=click.Choice(measures.keys()), 
         help="Measure to show")
 @click.option("-a", "--anonymous", is_flag=True, help="Hide usernames")
-@click.option("-s", "--short", is_flag=True, help="Show short module names")
+@click.option("-x", "--short", is_flag=True, help="Show short module names")
 @click.option("-o", "--outfile", help="Save results as csv")
 @click.option('-U', "--update", is_flag=True, help="Update repos first")
 @click.option('-t', "--threads", type=int, default=8, help="Maximum simultaneous threads")
-def status(config, group, course, user, unit, module, measure, anonymous, short, 
+def status(config, section, course, user, unit, module, measure, anonymous, short, 
         outfile, update, threads):
     "Show status of student repos by module"
     if update:
         from making_with_code_cli.teach.update import update as update_task
-        update_task.callback(config, group, course, user, unit, module, threads)
+        update_task.callback(config, section, course, user, unit, module, threads)
     settings = read_settings(config)
     if not check_required_teacher_settings(settings):
         return
     repos = StudentRepos(settings, threads)
     measure_status_message, measure_fn = measures[measure]
-    results = repos.apply(measure_fn, group=group, course=course, user=user, 
+    results = repos.apply(measure_fn, section=section, course=course, user=user, 
             unit=unit, module=module, status_message=measure_status_message)
     recursive_dict = lambda: defaultdict(recursive_dict)
     results_dict = recursive_dict()
     for r in results:
-        g = r['group']['group_name'] + ' | ' + r['group']['course_name']
-        results_dict[g][r['username']][r['module']] = r['score']
+        s = r['section']['name'] + ' | ' + r['section']['course_name']
+        results_dict[s][r['username']][r['module']] = r['score']
     all_scores = []
-    for group, users in results_dict.items():
+    for section, users in results_dict.items():
         if users:
             headers = ['username'] + sorted(next(iter(users.values())).keys())
-            group_scores = format_user_scores(users, anonymous, short)
-            all_scores += group_scores
+            section_scores = format_user_scores(users, anonymous, short)
+            all_scores += section_scores
             if not outfile:
-                click.echo(address(group))
-                click.echo(address(tabulate(group_scores, headers='keys'), 
+                click.echo(address(section))
+                click.echo(address(tabulate(section_scores, headers='keys'), 
                         preformatted=True))
     if outfile and all_scores:
         with open(outfile, 'w') as fh:
